# Biometrics Client

Client Library for the [Element Human](https://www.elementhuman.com) Biometrics API

The Biometrics API is capable of performing the following kinds of analyses:

   * face and eye localization though the computation of bounding boxes
   * emotion analysis by performing frame-by-frame facial coding
   * gaze location estimation


### Installation

```sh
pip install eh-biometrics-client
```

Requires Python 3.7+


### Documentation

Documentation for this package can be found [here](docs/README.md).


### Tests

Tests are provided and can be run via...

```sh
pytest -vv
```


### Bugs

Report any bugs in the issues section of github.  PRs are accepted!
